@@ -8,20 +8,12 @@ import sys
 import subprocess
 import argparse
 
-# Try local imports first (for development)
-try:
-    from src.model_checker import __version__
-    from src.model_checker.builder import (
-        BuildProject,
-        BuildModule,
-    )
-except ImportError:
-    # Fall back to installed package imports
-    from model_checker import __version__
-    from model_checker.builder import (
-        BuildProject,
-        BuildModule,
-    )
+# Standard imports
+from model_checker import __version__
+from model_checker.builder import (
+    BuildProject,
+    BuildModule,
+)
 
 
 class ParseFileFlags:
@@ -141,6 +133,12 @@ class ParseFileFlags:
             action='store_true',
             help='Overrides to print Z3 model or unsat_core.'
         )
+        parser.add_argument(
+            '--align_vertically',
+            '-a',
+            action='store_true',
+            help='Overrides to display world histories vertically with time flowing from top to bottom.'
+        )
         return parser
 
     def parse(self):
@@ -155,7 +153,34 @@ class ParseFileFlags:
                 - parsed_args: The parsed command line arguments
                 - package_name: The name of the package (model-checker)
         """
+        # Create a mapping from short flag names to long names
+        self._short_to_long = {
+            'c': 'contingent',
+            'd': 'disjoint',
+            'e': 'non_empty',
+            'l': 'load_theory',
+            'm': 'maximize',
+            'n': 'non_null',
+            'p': 'print_constraints',
+            's': 'save_output',
+            'i': 'print_impossible',
+            'v': 'version',
+            'u': 'upgrade',
+            'z': 'print_z3',
+            'a': 'align_vertically'
+        }
+        
+        # Store the original command line arguments
+        import sys
+        self._parsed_args = sys.argv[1:]
+        
+        # Parse the arguments
         self.flags = self.parser.parse_args()
+        
+        # Add the mapping and args to the flags object for use in settings manager
+        self.flags._short_to_long = self._short_to_long
+        self.flags._parsed_args = self._parsed_args
+        
         self.package_name = self.parser.prog
         return self.flags, self.package_name
 
@@ -180,6 +205,25 @@ def main():
 
     No parameters or return values as this is the main program entry point.
     """
+    # Check for Jupyter dependencies if they'll be needed
+    jupyter_flags = ["-j", "--jupyter", "-n", "--notebook"]
+    needs_jupyter = any(flag in sys.argv for flag in jupyter_flags)
+    
+    if needs_jupyter:
+        # Check for required dependencies if Jupyter features are requested
+        missing_deps = []
+        for pkg in ["ipywidgets", "matplotlib", "networkx"]:
+            try:
+                __import__(pkg)
+            except ImportError:
+                missing_deps.append(pkg)
+                
+        if missing_deps:
+            print(f"Error: The following required dependencies are missing: {', '.join(missing_deps)}")
+            print("To use Jupyter notebook features, install them with:")
+            print("  pip install model-checker[jupyter]")
+            return
+    
     if len(sys.argv) < 2:
         builder = BuildProject()
         builder.ask_generate()
