@@ -71,16 +71,10 @@ from z3 import (
     simplify,
 )
 
-# Try local imports first (for development)
-try:
-    from src.model_checker.utils import (
-        not_implemented_string,
-    )
-except ImportError:
-    # Fall back to installed package imports
-    from model_checker.utils import (
-        not_implemented_string,
-    )
+# Standard imports
+from model_checker.utils import (
+    not_implemented_string,
+)
 
 inputs_template = Template(
 '''Z3 run time: ${z3_model_runtime} seconds
@@ -133,8 +127,8 @@ class SemanticDefaults:
     Attributes:
         name (str): Name of the semantics implementation class
         N (int): Bit-width for state representation (if provided in settings)
-        full_bit (BitVecVal): Maximum possible state (if N is provided)
-        null_bit (BitVecVal): Empty state (if N is provided)
+        full_state (BitVecVal): Maximum possible state (if N is provided)
+        null_state (BitVecVal): Empty state (if N is provided)
         all_states (list): All possible bit vectors of width N (if N is provided)
         M (int): Number of times for temporal semantics (if provided in settings)
         all_times (list): All possible time points (if M is provided)
@@ -681,12 +675,6 @@ class ModelDefaults:
         if self.timeout or self.z3_model is None:
             return
 
-        # NOTE: this was moved to BuildExample to 
-        # Recursively update propositions
-        # for sent in self.premises + self.conclusions:
-        #     print(f"SENTENCE {sent}; TYPE {type(sent)}")
-        # self.interpret(self.premises + self.conclusions)
-
     def _process_solver_results(self, solver_results):
         """Process and store the results from the Z3 solver.
         
@@ -1100,11 +1088,74 @@ class ModelDefaults:
                 print(self.z3_model, file=output)
             else:
                 print(self.unsat_core, file=output)
-        if self.settings["print_z3"]:
-            if self.z3_model_status:
-                print(self.z3_model, file=output)
-            else:
-                print(self.unsat_core, file=output)
+                
+    def calculate_model_differences(self, previous_structure):
+        """Calculate theory-specific differences between this model and a previous one.
+        
+        This method identifies semantic differences that are meaningful in this theory's
+        context. The default implementation returns None, indicating that the basic
+        difference calculation should be used instead.
+        
+        Each theory should override this method to detect differences in its specific
+        semantic primitives, such as worlds, times, accessibility relations, etc.
+        
+        Args:
+            previous_structure: The previous model structure to compare against
+            
+        Returns:
+            dict: Theory-specific differences between the models, or None to use basic detection
+        """
+        # Default implementation returns None, meaning use basic difference detection
+        return None
+        
+    def print_model_differences(self, output=sys.stdout):
+        """Prints differences between this model and the previous one.
+        
+        Default implementation that provides basic difference display.
+        Theory-specific classes should override this to provide more detailed output.
+        
+        Args:
+            output (file, optional): Output stream to write to. Defaults to sys.stdout.
+        """
+        if not hasattr(self, 'model_differences') or not self.model_differences:
+            print("No previous model to compare with.", file=output)
+            return
+        
+        print("\n=== DIFFERENCES FROM PREVIOUS MODEL ===\n", file=output)
+        
+        # Print sentence letter differences
+        letter_diffs = self.model_differences.get('sentence_letters', {})
+        if letter_diffs:
+            print("Sentence Letter Changes:", file=output)
+            for letter, values in letter_diffs.items():
+                print(f"  {letter}: {values['old']} → {values['new']}", file=output)
+            print("", file=output)
+            
+        # Print semantic function differences
+        func_diffs = self.model_differences.get('semantic_functions', {})
+        if func_diffs:
+            print("Semantic Function Changes:", file=output)
+            for func_name, values in func_diffs.items():
+                print(f"  {func_name}:", file=output)
+                for input_val, change in values.items():
+                    print(f"    Input {input_val}: {change['old']} → {change['new']}", file=output)
+            print("", file=output)
+            
+        # Print model structure differences
+        struct_diffs = self.model_differences.get('model_structure', {})
+        if struct_diffs:
+            print("Model Structure Changes:", file=output)
+            for component, values in struct_diffs.items():
+                print(f"  {component}: {values['old']} → {values['new']}", file=output)
+            print("", file=output)
+        
+        # Print structural metrics if available
+        print("Structural Properties:", file=output)
+        print(f"  Worlds: {len(getattr(self, 'z3_world_states', []))}", file=output)
+            
+        # If the model is marked as isomorphic to a previous model, note that
+        if hasattr(self, 'isomorphic_to_previous') and self.isomorphic_to_previous:
+            print("NOTE: This model may be isomorphic to a previous model despite syntactic differences.", file=output)
 
     def print_info(self, model_status, default_settings, example_name, theory_name, output):
         """Print comprehensive model information and analysis results.
@@ -1136,7 +1187,11 @@ class ModelDefaults:
         # Print example information
         self._print_section_header(example_name, header, output)
         self._print_model_details(theory_name, output)
-        self._print_modified_settings(default_settings, output)
+        
+        # # NOTE: removed this functions
+        # # Use theory's DEFAULT_EXAMPLE_SETTINGS as the baseline for comparison
+        # theory_default_settings = self.model_constraints.semantics.DEFAULT_EXAMPLE_SETTINGS
+        # self._print_modified_settings(theory_default_settings, output)
         
         # Print constraints and runtime
         self.model_constraints.print_enumerate(output)
