@@ -7,14 +7,21 @@ Classes:
 
 Operators:
     default_operators: Dictionary of standard logical operators including:
-        - Extensional: ¬ (not), ∧ (and), ∨ (or), → (if), ↔ (iff)
+        - Extensional: ¬ (not), ∧ (and), ∨ (or), → (if), ←→ (iff)
         - Modal: □ (necessary), ◇ (possible)
         - Counterfactual: □→ (would), ◇→ (might)
         - Constitutive: ≡ (identical), ≤ (grounds), ⊑ (essence)
 
+Examples:
+    Access examples through utility functions in theory_lib:
+    - theory_lib.get_examples('default'): Gets the example_range dictionary
+    - theory_lib.get_test_examples('default'): Gets test example cases
+    - theory_lib.get_semantic_theories('default'): Gets semantic theory implementations
+
 Usage:
     from model_checker.theory_lib.default import Semantics, Proposition, ModelStructure
     from model_checker.theory_lib.default import default_operators
+    from model_checker.theory_lib import get_examples
 
     # Create a semantics and model structure
     semantics = Semantics(settings)
@@ -23,16 +30,11 @@ Usage:
     # Evaluate formulas
     prop = Proposition(formula, model)
     result = prop.evaluate()
+    
+    # Access examples
+    examples = get_examples('default')
 """
 
-__version__ = "0.0.1"
-
-# Define the public API of the package
-__all__ = [
-    "Semantics", "Proposition", "ModelStructure",  # semantic
-    "default_operators",  # operators
-]
-
 # Import specific items from semantic
 from .semantic import (
     Semantics,
@@ -43,5 +45,13 @@ from .semantic import (
 # Import all operators
 from .operators import default_operators
 
-# NOTE: this will cause circular imports
-# from .examples import example_range
+__version__ = "unknown"
+
+# Define the public API of the package
+__all__ = [
+    "Semantics",         # Configures semantic framework and evaluation rules
+    "Proposition",       # Represents and evaluates logical formulas
+    "ModelStructure",    # Manages model's state space and accessibility relations
+    "default_operators", # Standard logical operators (¬,∧,∨,→,←→,□,◇,etc.)
+    "__version__",       # Package version information
+]
