@@ -68,23 +68,16 @@ Notes:
 - The example_range can be modified to run different subsets of tests
 """
 
-import os
-import sys
-# Add the current directory to sys.path
-sys.path.append(os.path.dirname(__file__))
-
-from semantic import (
+# Standard imports
+from .semantic import (
     Semantics,
     Proposition,
     ModelStructure,
 )
-from operators import (
-    default_operators,
-)
+from .operators import default_operators
 
 __all__ = [
     'general_settings',
-    'example_settings',
     'default_theory',
     'semantic_theories',
     'example_range',
@@ -96,20 +89,12 @@ __all__ = [
 
 general_settings = {
     "print_constraints": False,
-    "print_impossible": False,
+    "print_impossible": True,
     "print_z3": False,
     "save_output": False,
     "maximize": False,
 }
 
-example_settings = {  # defaults can be tailored to each example
-    'N' : 3,
-    'contingent' : False,
-    'disjoint' : False,
-    'non_empty' : False,
-    'non_null' : False,
-    'max_time' : 1,
-}
 
 
 ####################################
@@ -738,7 +723,7 @@ CL_CM_10_example = [
 CF_TH_1_premises = []
 CF_TH_1_conclusions = ['(A \\boxright A)']
 CF_TH_1_settings = {
-    'N' : 4,
+    'N' : 2,
     'contingent' : False,
     'disjoint' : False,
     'non_empty' : False,
@@ -1223,7 +1208,7 @@ example_range = {
     # "ML_CM_1" : ML_CM_1_example,
 
     # Counterfactual Theorems
-    "CF_TH_1" : CF_TH_1_example,
+    # "CF_TH_1" : CF_TH_1_example,
     # "CF_TH_2" : CF_TH_2_example,
     # "CF_TH_3" : CF_TH_3_example,
     # "CF_TH_4" : CF_TH_4_example,
