@@ -80,42 +80,28 @@ More information can be found in the README.md for the exclusion theory.
 ### DEFINE THE IMPORTS ###
 ##########################
 
-import os
-import sys
-# Add the current directory to sys.path
-sys.path.append(os.path.dirname(__file__))
-
 # Exclusion
-from semantic import (
+from .semantic import (
     ExclusionSemantics,
     UnilateralProposition,
     ExclusionStructure,
 )
-from operators import exclusion_operators
+from .operators import exclusion_operators
 
 # Default + Utils
-try: # Try local imports first (for development)
-    from src.model_checker.theory_lib.default import (
-        Semantics,
-        Proposition,
-        ModelStructure,
-        default_operators,
-    )
-except ImportError:
-    # Fall back to installed package imports
-    from model_checker.theory_lib.default import (
-        Semantics,
-        Proposition,
-        ModelStructure,
-        default_operators,
-    )
+from model_checker.theory_lib.default import (
+    Semantics,
+    Proposition,
+    ModelStructure,
+    default_operators,
+)
 
 __all__ = [
     'general_settings',
     'example_settings',
     'exclusion_theory',
     'semantic_theories',
-    'example_range',
+    'test_example_range',
 ]
 
 ####################################
@@ -865,8 +851,7 @@ semantic_theories = {
     # "Brast-McKie" : default_theory,
 }
 
-# NOTE: at least one example is required, multiple are permitted for comparison
-example_range = {
+test_example_range = {
     # Countermodels
     "EX_CM_0" : EX_CM_0_example,
     "EX_CM_1" : EX_CM_1_example,
@@ -901,9 +886,42 @@ example_range = {
     "EX_CM_6" : EX_CM_6_example,
     "EX_CM_7" : EX_CM_7_example,
     "EX_CM_14" : EX_CM_14_example,
-
-    # Testing
-    # "UNIEQUIV PLAYGROUND" : UNIEQUIV_PLAYGROUND
 }
 
+# NOTE: at least one example is required, multiple are permitted for comparison
+example_range = {
+    # Countermodels
+    "EX_CM_0" : EX_CM_0_example,
+    # "EX_CM_1" : EX_CM_1_example,
+    # "EX_CM_5" : EX_CM_5_example,
+    # "EX_CM_8" : EX_CM_8_example,
+    # "EX_CM_9" : EX_CM_9_example,
+    # "EX_CM_10" : EX_CM_10_example,
+    # "EX_CM_11" : EX_CM_11_example,
+    # "EX_CM_12" : EX_CM_12_example,
+    # "EX_CM_13" : EX_CM_13_example,
 
+    # Theorems
+    "EX_TH_1" : EX_TH_1_example,
+    # "EX_TH_2" : EX_TH_2_example,
+    # "EX_TH_3" : EX_TH_3_example,
+    # "EX_TH_4" : EX_TH_4_example,
+    # "EX_TH_5" : EX_TH_5_example,
+    # "EX_TH_6" : EX_TH_6_example,
+    # "EX_TH_7" : EX_TH_7_example,
+    # "EX_TH_8" : EX_TH_8_example,
+    # "EX_TH_9" : EX_TH_9_example,
+    # "EX_TH_10" : EX_TH_10_example,
+    # "EX_TH_11" : EX_TH_11_example,
+    # "EX_TH_12" : EX_TH_12_example,
+    # "EX_TH_13" : EX_TH_13_example,
+    # "EX_TH_14" : EX_TH_14_example,
+    # "EX_TH_15" : EX_TH_15_example,
+    # "EX_TH_16" : EX_TH_16_example,
+    # "EX_CM_2" : EX_CM_2_example,
+    # "EX_CM_3" : EX_CM_3_example,
+    # "EX_CM_4" : EX_CM_4_example,
+    # "EX_CM_6" : EX_CM_6_example,
+    # "EX_CM_7" : EX_CM_7_example,
+    # "EX_CM_14" : EX_CM_14_example,
+}
