@@ -7,26 +7,15 @@ import sys
 import time
 
 
-try: # Try local imports first (for development)
-    from src.model_checker.utils import (
-        ForAll,
-        Exists,
-        bitvec_to_substates,
-        pretty_set_print,
-        int_to_binary,
-    )
-    from src.model_checker import model
-    from src.model_checker import syntactic
-except ImportError:
-    from model_checker.utils import (
-        ForAll,
-        Exists,
-        bitvec_to_substates,
-        pretty_set_print,
-        int_to_binary,
-    )
-    from model_checker import model
-    from model_checker import syntactic
+from model_checker.utils import (
+    ForAll,
+    Exists,
+    bitvec_to_substates,
+    pretty_set_print,
+    int_to_binary,
+)
+from model_checker import model
+from model_checker import syntactic
 
 class ExclusionSemantics(model.SemanticDefaults):
 
@@ -42,6 +31,15 @@ class ExclusionSemantics(model.SemanticDefaults):
         'max_time' : 1,
         'expectation' : None,
     }
+    
+    # Default general settings for the exclusion theory
+    DEFAULT_GENERAL_SETTINGS = {
+        "print_impossible": False,
+        "print_constraints": False,
+        "print_z3": False,
+        "save_output": False,
+        "maximize": False,
+    }
 
     def __init__(self, combined_settings): # TODO: 
 
@@ -400,7 +398,7 @@ class UnilateralProposition(model.PropositionDefaults):
 
         self.z3_model = model_structure.z3_model
         self.eval_world = model_structure.main_point["world"] if eval_world == 'main' else eval_world
-        self.all_bits = model_structure.all_bits
+        self.all_states = model_structure.all_states
         self.verifiers = self.find_proposition()
         self.precluders = self.find_precluders(self.verifiers)
 
@@ -430,9 +428,9 @@ class UnilateralProposition(model.PropositionDefaults):
     def find_precluders(self, py_verifier_set):
         z3_verifier_set = self.semantics.z3_set(py_verifier_set, self.N)
         precludes = self.semantics.precludes
-        all_bits = self.semantics.all_bits
+        all_states = self.semantics.all_states
         result = set()
-        for state in all_bits:
+        for state in all_states:
             preclude_formula = precludes(state, z3_verifier_set)
             preclude_result = self.z3_model.evaluate(preclude_formula)
             # Check if the evaluated result is True
@@ -603,7 +601,7 @@ class UnilateralProposition(model.PropositionDefaults):
     def find_proposition(self):
         """takes self, returns the V, F tuple
         used in find_verifiers"""
-        all_bits = self.model_structure.all_bits
+        all_states = self.model_structure.all_states
         model = self.model_structure.z3_model
         semantics = self.semantics
         eval_world = self.eval_world
@@ -612,7 +610,7 @@ class UnilateralProposition(model.PropositionDefaults):
         sentence_letter = self.sentence_letter
         if sentence_letter is not None:
             V = {
-                bit for bit in all_bits
+                bit for bit in all_states
                 if model.evaluate(semantics.verify(bit, sentence_letter))
             }
             return V
@@ -670,7 +668,7 @@ class ExclusionStructure(model.ModelDefaults):
             for bit in self.all_states
             if evaluate(self.semantics.possible(bit))
         ]
-        self.z3_world_bits = [
+        self.z3_world_states = [
             bit
             for bit in self.all_states
             if evaluate(self.semantics.is_world(bit))
@@ -734,7 +732,7 @@ class ExclusionStructure(model.ModelDefaults):
             bin_rep = binary_bitvector(bit)
             if bit == 0:
                 format_state(bin_rep, state, self.COLORS["initial"])
-            elif bit in self.z3_world_bits:
+            elif bit in self.z3_world_states:
                 format_state(bin_rep, state, self.COLORS["world"], "world")
             elif bit in self.z3_poss_bits:
                 format_state(bin_rep, state, self.COLORS["possible"])
@@ -770,13 +768,13 @@ class ExclusionStructure(model.ModelDefaults):
                             continue
 
         # print()
-        # for bit_x in self.all_bits:
-        #     for bit_y in self.all_bits:
+        # for bit_x in self.all_states:
+        #     for bit_y in self.all_states:
         #         if self.z3_model.evaluate(self.semantics.conflicts(bit_x, bit_y)):
         #             print(f"CONFLICT: {bitvec_to_substates(bit_x, self.N)} conflicts with {bitvec_to_substates(bit_y, self.N)}")
-        #             for bit_u in self.all_bits:
+        #             for bit_u in self.all_states:
         #                 if self.z3_model.evaluate(self.semantics.is_part_of(bit_u, bit_x)):
-        #                     for bit_v in self.all_bits:
+        #                     for bit_v in self.all_states:
         #                         if self.z3_model.evaluate(self.semantics.is_part_of(bit_v, bit_y)):
         #                             if self.z3_model.evaluate(self.semantics.excludes(bit_u, bit_v)):
         #                                 print(f"EXCLUDERS: {bitvec_to_substates(bit_u, self.N)} excludes {bitvec_to_substates(bit_v, self.N)}\n")
@@ -785,7 +783,7 @@ class ExclusionStructure(model.ModelDefaults):
         """prints states, sentence letters evaluated at the designated world and
         recursively prints each sentence and its parts"""
         model_status = self.z3_model_status
-        self.print_info(model_status, default_settings, example_name, theory_name, output)
+        self.print_info(model_status, self.settings, example_name, theory_name, output)
         if model_status:
             self.print_states(output)
             self.print_exclusion(output)
@@ -807,19 +805,22 @@ class ExclusionStructure(model.ModelDefaults):
         """
         if print_constraints is None:
             print_constraints = self.settings["print_constraints"]
-        if self.timeout:
-            print(f"TIMEOUT: {self.timeout}")
+        # Check if we actually timed out (runtime >= max_time)
+        actual_timeout = hasattr(self, 'z3_model_runtime') and self.z3_model_runtime >= self.max_time
+        
+        # Only show timeout if we really timed out and didn't find a model
+        if actual_timeout and (not hasattr(self, 'z3_model') or self.z3_model is None):
+            print(f"\nTIMEOUT: Model search exceeded maximum time of {self.max_time} seconds", file=output)
             print(f"No model for example {example_name} found before timeout.", file=output)
             print(f"Try increasing max_time > {self.max_time}.\n", file=output)
-            return
-        self.print_all(default_settings, example_name, theory_name, output)
+        self.print_all(self.settings, example_name, theory_name, output)
         if print_constraints and self.unsat_core is not None:
             self.print_grouped_constraints(output)
 
     def save_to(self, example_name, theory_name, include_constraints, output):
         """append all elements of the model to the file provided"""
         constraints = self.model_constraints.all_constraints
-        self.print_all(example_name, theory_name, output)
+        self.print_all(self.settings, example_name, theory_name, output)
         self.build_test_file(output)
         if include_constraints:
             print("# Satisfiable constraints", file=output)
