@@ -83,36 +83,23 @@ More information can be found in the README.md for the exclusion theory.
 ### DEFINE THE IMPORTS ###
 ##########################
 
-import sys
-import os
-sys.path.append(os.path.dirname(__file__))  # Add the current directory to sys.path
-
-from semantic import ImpositionSemantics
-from operators import imposition_operators
+from .semantic import ImpositionSemantics
+from .operators import imposition_operators
 
 # Default
-try: # Try local imports first (for development)
-    from src.model_checker.theory_lib.default import (
-        Semantics,
-        Proposition,
-        ModelStructure,
-        default_operators,
-    )
-except ImportError:
-    # Fall back to installed package imports
-    from model_checker.theory_lib.default import (
-        Semantics,
-        Proposition,
-        ModelStructure,
-        default_operators,
-    )
+from model_checker.theory_lib.default import (
+    Semantics,
+    Proposition,
+    ModelStructure,
+    default_operators,
+)
 
 __all__ = [
     'general_settings',
     'example_settings',
     'imposition_theory',
     'semantic_theories',
-    'example_range',
+    'test_example_range',
 ]
 
 
@@ -826,15 +813,13 @@ CF_TH_12_example = [
 
 # NOTE: at least one theory is required, multiple are permitted for comparison
 semantic_theories = {
-    "Brast-McKie" : default_theory,
     "Fine" : imposition_theory,
+    # "Brast-McKie" : default_theory,
     # additional theories will require their own translation dictionaries
 }
 
-# NOTE: at least one example is required, multiple are permitted for comparison
-example_range = {
+test_example_range = {
     # Counterfactual Countermodels
-    # "CF_CM_0" : CF_CM_0_example,
     "CF_CM_1" : CF_CM_1_example,
     "CF_CM_2" : CF_CM_2_example,
     "CF_CM_3" : CF_CM_3_example,
@@ -871,3 +856,43 @@ example_range = {
     "CF_TH_11" : CF_TH_11_example,
     "CF_TH_12" : CF_TH_12_example,
 }
+
+# NOTE: at least one example is required, multiple are permitted for comparison
+example_range = {
+    # Counterfactual Countermodels
+    "CF_CM_1" : CF_CM_1_example,
+    # "CF_CM_2" : CF_CM_2_example,
+    # "CF_CM_3" : CF_CM_3_example,
+    # "CF_CM_4" : CF_CM_4_example,
+    # "CF_CM_5" : CF_CM_5_example,
+    # "CF_CM_6" : CF_CM_6_example,
+    # "CF_CM_7" : CF_CM_7_example,
+    # "CF_CM_8" : CF_CM_8_example,
+    # "CF_CM_9" : CF_CM_9_example,
+    # "CF_CM_10" : CF_CM_10_example,
+    # "CF_CM_11" : CF_CM_11_example,
+    # "CF_CM_12" : CF_CM_12_example,
+    # "CF_CM_13" : CF_CM_13_example,
+    # "CF_CM_14" : CF_CM_14_example,
+    # "CF_CM_15" : CF_CM_15_example,
+    # "CF_CM_16" : CF_CM_16_example,
+    # "CF_CM_17" : CF_CM_17_example,
+    # "CF_CM_18" : CF_CM_18_example,
+    # "CF_CM_19" : CF_CM_19_example,
+    # "CF_CM_20" : CF_CM_20_example,
+    # "CF_CM_21" : CF_CM_21_example,
+
+    # Counterfactual Theorems
+    "CF_TH_1" : CF_TH_1_example,
+    # "CF_TH_2" : CF_TH_2_example,
+    # "CF_TH_3" : CF_TH_3_example,
+    # "CF_TH_4" : CF_TH_4_example,
+    # "CF_TH_5" : CF_TH_5_example,
+    # "CF_TH_6" : CF_TH_6_example,
+    # "CF_TH_7" : CF_TH_7_example,
+    # "CF_TH_8" : CF_TH_8_example,
+    # "CF_TH_9" : CF_TH_9_example,
+    # "CF_TH_10" : CF_TH_10_example,
+    # "CF_TH_11" : CF_TH_11_example,
+    # "CF_TH_12" : CF_TH_12_example,
+}
