@@ -29,10 +29,10 @@ from model_checker.theory_lib.imposition import (
     ImpositionSemantics,
     imposition_operators,
 )
-from model_checker.theory_lib.imposition.examples import example_range
+from model_checker.theory_lib.imposition.examples import test_example_range
 from model_checker.utils import run_test
 
-@pytest.mark.parametrize("example_name,example_case", example_range.items())
+@pytest.mark.parametrize("example_name,example_case", test_example_range.items())
 def test_example_cases(example_name, example_case):
     """Test each example case from example_range."""
     result = run_test(
