@@ -32,11 +32,15 @@ def parse_expression(tokens):
         raise ValueError("Empty token list")
     token = tokens.pop(0)  # Get the next token
     if token == "(":  # Handle binary operator case (indicated by parentheses)
+        if not tokens:  # Check if tokens are empty after removing first token
+            raise ValueError(f"Empty token list after opening parenthesis")
         closing_parentheses = tokens.pop()  # Remove the closing parenthesis
         if closing_parentheses != ")":
             raise SyntaxError(
                 f"The sentence {tokens} is missing a closing parenthesis."
             )
+        if not tokens:  # Check if tokens are empty after removing parentheses
+            raise ValueError(f"Empty token list after removing parentheses")
         operator, left, right = op_left_right(tokens)
         left_arg, left_comp = parse_expression(left)  # Parse the left argument
         right_arg, right_comp = parse_expression(right)  # Parse the right argument
@@ -44,8 +48,15 @@ def parse_expression(tokens):
         return [operator, left_arg, right_arg], complexity 
     if token.isalnum():  # Handle atomic sentences
         return [token], 0
-    elif token in {"\\top", "\\bot"}:  # Handle extremal operators
-        return [token], 0
+    elif token.startswith("\\"):  # Handle all LaTeX operators 
+        # This includes: \top, \bot, \Future, \Past, \future, \past, etc.
+        # Special case for nullary operators like \top and \bot
+        if token in {"\\top", "\\bot"}:
+            return [token], 0
+        if not tokens:  # Check if tokens are empty after operator
+            raise ValueError(f"Empty token list after operator {token}")
+        arg, comp = parse_expression(tokens)
+        return [token, arg], comp + 1
     arg, comp = parse_expression(tokens)
     return [token, arg], comp + 1 
 
@@ -222,8 +233,23 @@ def index_to_substate(index):
 #     raise ValueError("should have run into 'b' at the end but didn't")
 
 
+# TODO: refactor creating a worlds-specific function
 def bitvec_to_substates(bit_vec, N):
     '''converts bitvectors to fusions of atomic states.'''
+    # Safety check for non-BitVec objects
+    if not hasattr(bit_vec, 'sexpr'):
+        # Handle the case where we don't have a proper BitVec
+        if hasattr(bit_vec, '__int__'):
+            # If it can be converted to int, use that
+            return bitvec_to_substates(BitVecVal(int(bit_vec), N), N)
+        else:
+            # Check if it's a Z3 QuantifierRef or other Z3 object
+            if hasattr(bit_vec, 'ast') or hasattr(bit_vec, 'ctx'):
+                # It's a Z3 object but not a BitVec - return a placeholder
+                return f"<z3-obj>"
+            # Fall back to a safe representation
+            return f"<unknown-{str(bit_vec)}>"
+    
     bit_vec_as_string = bit_vec.sexpr()
     
     # Handle different formats of bit vector representation
@@ -265,6 +291,51 @@ def bitvec_to_substates(bit_vec, N):
     return state_repr[:-1] if state_repr else "□"
 
 
+def bitvec_to_worldstate(bit_vec, N=None):
+    """Converts a bitvector to a simple alphabetic world state label.
+    
+    Maps bitvector values to letters: 0→a, 1→b, 2→c, ..., 25→z, 26→aa, 27→bb, etc.
+    
+    Args:
+        bit_vec: Z3 bitvector or integer value
+        N: number of bits (optional, only used for error handling)
+        
+    Returns:
+        A string representation of the world state using letters
+    """
+    try:
+        # Get integer value from bitvector
+        if hasattr(bit_vec, 'as_long'):
+            value = bit_vec.as_long()
+        elif hasattr(bit_vec, 'sexpr'):
+            # Handle different formats of bit vector representation
+            bit_vec_as_string = bit_vec.sexpr()
+            if 'x' in bit_vec_as_string:  # hexadecimal format
+                value = int(bit_vec_as_string[2:], 16)
+            elif bit_vec_as_string.startswith('#b'):  # binary format
+                value = int(bit_vec_as_string[2:], 2)
+            else:  # decimal format
+                value = int(bit_vec_as_string)
+        elif isinstance(bit_vec, int):
+            value = bit_vec
+        else:
+            return f"<unknown-{bit_vec}>"
+            
+        # Convert integer to letter representation
+        if value < 26:
+            # Single letter for values 0-25 (a-z)
+            return chr(97 + value)  # ASCII 'a' starts at 97
+        else:
+            # Double letters for values >= 26 (aa, bb, etc.)
+            letter_idx = value % 26
+            repeat = value // 26 + 1
+            letter = chr(97 + letter_idx)
+            return letter * repeat
+            
+    except (AttributeError, ValueError):
+        return f"<unknown-{bit_vec}>"
+
+
 ### Z3 HELPERS ###
 
 # def z3_set_to_python_set(z3_set, domain):
@@ -399,18 +470,55 @@ def get_example(name, example_range):
         raise KeyError(f"Example {name} not found. Available examples: {list(example_range.keys())}")
     return example_range[name]
 
-def get_theory(name, semantic_theories):
-    """Get a specific semantic theory by name from the provided theories
+def get_theory(name, semantic_theories=None):
+    """Get a specific semantic theory by name
+    
+    This function can be called in two ways:
+    1. With just the theory name (e.g., 'default') - will automatically load the semantic theories
+    2. With both name and semantic_theories - useful when you already have the semantic theories loaded
     
     Args:
-        name (str): Name of the theory to retrieve
-        semantic_theories (dict): Dictionary containing the semantic theories
+        name (str): Name of the theory to retrieve (e.g., 'default', 'exclusion')
+        semantic_theories (dict, optional): Dictionary containing semantic theories. 
+                                           If None, will be loaded automatically.
         
     Returns:
         dict: Dictionary containing semantics, proposition, model, and operators
+        
+    Raises:
+        ValueError: If the theory name is not found or the theory_lib module can't be loaded
+        KeyError: If the specific theory is not found in the semantic_theories
     """
+    # If semantic_theories is not provided, try to load it
+    if semantic_theories is None:
+        try:
+            # Import here to avoid circular imports
+            from model_checker.theory_lib import get_semantic_theories
+            semantic_theories = get_semantic_theories(name)
+        except ImportError as e:
+            available_theories = []
+            try:
+                from model_checker.theory_lib import AVAILABLE_THEORIES
+                available_theories = AVAILABLE_THEORIES
+            except ImportError:
+                pass
+            
+            raise ValueError(f"Could not load theory_lib module. Available theories: {available_theories}") from e
+        except ValueError as e:
+            raise ValueError(f"Theory '{name}' not found in theory_lib") from e
+    
+    # Handle special case for default theory which may have a different name
+    if name == "default" and "default" not in semantic_theories and "Brast-McKie" in semantic_theories:
+        return semantic_theories["Brast-McKie"]
+    
+    # For theories with only one variant, return that variant regardless of name
+    if len(semantic_theories) == 1:
+        return list(semantic_theories.values())[0]
+    
+    # Standard case - look up the theory by name
     if name not in semantic_theories:
-        raise KeyError(f"Theory {name} not found. Available theories: {list(semantic_theories.keys())}")
+        raise KeyError(f"Theory '{name}' not found. Available theories: {list(semantic_theories.keys())}")
+    
     return semantic_theories[name]
 
 
